/****************************************************************
 *								*
 * Copyright (c) 2009-2018 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef LOOKUP_VARIABLE_HTENT_H_INCLUDED
#define LOOKUP_VARIABLE_HTENT_H_INCLUDED

ht_ent_mname *lookup_variable_htent(unsigned int x);

#endif
